""" Module that defines translation logic and google api integration
"""
import urllib
import urllib2
try:
    import json
except ImportError:
    # Fix Python 2.4 and Python 2.5 compatibility
    import simplejson as json

_GOOGLE_URL = \
        "http://ajax.googleapis.com/ajax/services/language/translate?v=1.0"

# Max num of characters that google API accepts
_GOOGLE_CHUNK_SIZE = 500

class InvalidLanguagePairError(Exception):
    """ InvalidLanguagePairError exception
    """
    pass

class ServiceUnavailableError(Exception):
    """ ServiceUnavailableError exception
    """
    pass

def translate(src, langpair='se|en'):
    """ Translate a word or sentance using google translate.

        'src' (string/unicode) is the word or sentance to translate.
        'langpair' is the languages to translate from and to. Use the format
        <src_lang>|<dst_lang>.

        Input is unicode or utf-8 encoded str. Returns unicode.
    """
    if isinstance(src, unicode):
        src = src.encode('utf-8')
    variables = [('q', src), ('langpair', langpair)]
    url = _GOOGLE_URL + '&' + urllib.urlencode(variables)
    response = urllib2.urlopen(url)
    json_data = json.load(response)
    if json_data == None:
        raise ServiceUnavailableError, 'Sorry, translation service unavailable'
    elif json_data['responseStatus'] == 400:
        raise InvalidLanguagePairError, json_data['responseDetails']
    return unicode(json_data['responseData']['translatedText'])

def translate_plus(src, langpair='se|en'):
    """ Like translate, but chops the input into sentances to avoid exceeding
        the Google Translate character limit.

        Input is unicode or utf-8 encoded str. Returns unicode.
    """
    dst = [translate(i.strip(), langpair) for i in src.split('.') if i != '']
    return u'. '.join(dst)
